package org.artifactory.release.bundle;

import lombok.AccessLevel;
import lombok.NoArgsConstructor;
import lombok.NonNull;
import org.apache.commons.lang3.tuple.Pair;
import org.artifactory.api.rest.distribution.bundle.models.ArtifactsBundleModel;
import org.artifactory.repo.RepoPath;
import org.artifactory.repo.RepoPathFactory;
import org.artifactory.storage.db.bundle.model.DBArtifactsBundle;

import static org.artifactory.repo.system.SystemRepos.IN_TRANSIT_REPO_KEY;

/**
 * @author Eli Skoran 09/09/2020
 */
@NoArgsConstructor(access = AccessLevel.PRIVATE)
public class ReleaseBundleUtils {

    @NonNull
    public static RepoPath buildExportFileRepoPath(
            @NonNull String bundleName,
            @NonNull String bundleVersion,
            @NonNull String storingRepo
    ) {
        String repoPath = String.format("%s/%s/%s-%s.zip", bundleName, bundleVersion, bundleName, bundleVersion);
        return RepoPathFactory.create(storingRepo, repoPath);
    }

    @NonNull
    public static ArtifactsBundleModel convertToArtifactsBundleModel(@NonNull DBArtifactsBundle artifactsBundle) {
        return new ArtifactsBundleModel(
                artifactsBundle.getId(),
                artifactsBundle.getName(),
                artifactsBundle.getVersion(),
                artifactsBundle.getStatus(),
                artifactsBundle.getType(),
                artifactsBundle.getStoringRepo()
        );
    }

    @NonNull
    public static String generateTransactionPath(@NonNull String bundleName, @NonNull String bundleVersion) {
        return String.join("/", IN_TRANSIT_REPO_KEY, bundleName, bundleVersion);
    }

    @NonNull
    public static Pair<String, String> extractReleaseBundleNameAndVersion(@NonNull String transactionPath) {
        String[] transactionParts = transactionPath.split("/");
        if (transactionParts.length != 3) {
            throw new IllegalArgumentException(
                    "Unexpected Formatting of the transactionPath. expecting 3 parts separated by '/' but got: " +
                            transactionPath);
        }
        return Pair.of(transactionParts[1], transactionParts[2]);
    }

}
