#!/usr/bin/env bash

set -e

export PROJECT_ROOT_DIR="$(cd "$(dirname "${BASH_SOURCE[0]}")" && cd ../../.. && pwd)"
source "${PROJECT_ROOT_DIR}/build/ci/scripts/lib/buildInfoUtils.sh"
source "${PROJECT_ROOT_DIR}/build/ci/scripts/lib/versionUtils.sh"
source "${PROJECT_ROOT_DIR}/build/ci/scripts/lib/mavenUtils.sh"

cd "${PROJECT_ROOT_DIR}/artifactory-oss"


function on_start() {
  local projectListArg
  local version revision
  version=$(maven_getVersionFromPom pom.xml)
  revision=$(version_getRevisionFromVersion ${version})
  export MAVEN_EXTRA_CONFIG="${MAVEN_CONFIG} -Dartifactory.revision.prop=${revision}"
  "${PROJECT_ROOT_DIR}/build/ci/scripts/javaGenerateConfig.sh"
  buildInfo_setBuildNameAndNumber
  export MVN_COMMAND="install -DskipTests ${MAVEN_EXTRA_CONFIG}"
}

function on_success() {
  local version branch
  branch="$(pipeline_gitBranchName)"
  version=$(maven_getVersionFromPom "pom.xml")
  buildInfo_modifyBuildName "${JFROG_CLI_BUILD_NAME}" "${JFROG_CLI_BUILD_NUMBER}"
  buildInfo_publish
  write_output artifactory_oss_java_module_build_info buildName="${JFROG_CLI_BUILD_NAME}" buildNumber="${JFROG_CLI_BUILD_NUMBER}" version="${version}"
  save_classes_for_tests
  if ! common_isReleaseOrMilestoneBranch "${branch}" && [[ "${RUN_DB_TESTS}" != true ]] ; then
  # if ! common_isReleaseOrMilestoneBranch "${branch}"; then
    echo "Not a release/milestone branch - skipping artifactory db_unittest Jenkins job"
  else
    echo "buildNumber=\"${JFROG_CLI_BUILD_NUMBER}\" branch=\"${branch}\" repository=$(maven_devArtifactRepoName \"${branch}\")"
    write_output artifactory_release_dev_db_unittest_trigger_property_bag buildNumber="${JFROG_CLI_BUILD_NUMBER}" branch="${branch}" repository=$(maven_devArtifactRepoName "${branch}")
  fi

}

function save_classes_for_tests() {
    local cache_dir="${run_dir}/${step_affinity_group}_cache_classes"
    local state_cache_dir="${PROJECT_ROOT_DIR}/artifactory-oss"
    local run_state_cache_dir="${cache_dir}/dir_cache"
    if mkdir -p "${run_state_cache_dir}" && cp -r "${state_cache_dir}"/* "${run_state_cache_dir}"; then
        echo "Dir state was cached." >&2
    else
        echo "=> ERROR: Can't save dir state to the cache." >&2
        return 1
    fi

    echo "ls ${run_state_cache_dir}"
    ls ${run_state_cache_dir}

}
