/*
 *
 * Artifactory is a binaries repository manager.
 * Copyright (C) 2018 JFrog Ltd.
 *
 * Artifactory is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 * Artifactory is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with Artifactory.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

package org.artifactory.ui.rest.model.general;

import com.fasterxml.jackson.annotation.JsonProperty;
import lombok.Getter;
import lombok.Setter;
import org.artifactory.descriptor.message.SystemMessageDescriptor;
import org.jfrog.common.platform.subscription.SubscriptionType;


/**
 * @author Chen Keinan
 */
@Getter
@Setter
public class FooterImpl extends BaseFooterImpl implements Footer {
    private String versionInfo;
    private String buildNumber;
    private String licenseInfo;
    private String copyRights;
    private String copyRightsUrl;
    private boolean isDedicatedAol;
    private boolean isHttpSsoEnabledAOL;
    private boolean helpLinksEnabled;
    private boolean systemMessageEnabled;
    private String systemMessageTitle;
    private String systemMessageTitleColor;
    private String systemMessage;
    private boolean showSystemMessageOnAllPages;
    private String serverId;
    private boolean trashDisabled;
    private boolean allowPermDeletes;
    private boolean samlRedirectEnabled;
    private boolean xrayConfigured;
    private boolean xrayEnabled;
    private boolean xrayLicense;
    private boolean edgeLicense;
    private boolean mdsPackageNativeUI;
    private boolean metadataMigrationInProgress;
    private boolean isCloudProviderConfigured;
    private boolean treebrowserFolderCompact;
    private boolean archiveIndexEnabled;
    private String dateFormat;
    private String userEmail;
    private String subscriptionTierType;
    // show version and license version in standalone mode
    private boolean showDetailedFooter;

    public FooterImpl(String licenseInfo, String versionInfo, String copyRights, String copyRightsUrl,
            String buildNumber, boolean isAol, boolean isDedicatedAol, boolean isHttpSsoEnabledAOL, String versionID,
            boolean userLogo, String logoUrl, String serverName, SubscriptionType subscriptionType,
            SystemMessageDescriptor systemMessageDescriptor,
            boolean helpLinksEnabled, String serverId, boolean trashDisabled, boolean allowPermDeletes,
            boolean samlRedirectEnabled, boolean xrayConfigured, boolean xrayEnabled, boolean xrayLicense,
            boolean haConfigured, boolean gaAccount, boolean edgeLicense, boolean mdsPackageNativeUI,
            boolean isCloudProviderConfigured, String platformId, boolean treebrowserFolderCompact, String dateFormat,
            boolean metadataMigrationInProgress, boolean archiveIndexEnabled, String userEmail,
            boolean showDetailedFooter) {
        super(serverName, userLogo, logoUrl, haConfigured, isAol, versionID, gaAccount, platformId);
        this.licenseInfo = licenseInfo;
        this.versionInfo = versionInfo;
        this.copyRights = copyRights;
        this.copyRightsUrl = copyRightsUrl;
        this.buildNumber = buildNumber;
        this.isDedicatedAol = isDedicatedAol;
        this.isHttpSsoEnabledAOL = isHttpSsoEnabledAOL;
        this.trashDisabled = trashDisabled;
        this.allowPermDeletes = allowPermDeletes;
        this.systemMessageEnabled = systemMessageDescriptor.isEnabled();
        this.systemMessageTitle = systemMessageDescriptor.getTitle();
        this.systemMessageTitleColor = systemMessageDescriptor.getTitleColor();
        this.systemMessage = systemMessageDescriptor.getMessage();
        this.showSystemMessageOnAllPages = systemMessageDescriptor.isShowOnAllPages();
        this.helpLinksEnabled = helpLinksEnabled;
        this.serverId = serverId;
        this.samlRedirectEnabled = samlRedirectEnabled;
        this.xrayConfigured = xrayConfigured;
        this.xrayEnabled = xrayEnabled;
        this.xrayLicense = xrayLicense;
        this.edgeLicense = edgeLicense;
        this.mdsPackageNativeUI = mdsPackageNativeUI;
        this.isCloudProviderConfigured = isCloudProviderConfigured;
        this.metadataMigrationInProgress = metadataMigrationInProgress;
        this.treebrowserFolderCompact = treebrowserFolderCompact;
        this.dateFormat = dateFormat;
        this.userEmail = userEmail;
        this.archiveIndexEnabled = archiveIndexEnabled;
        if (subscriptionType != null) {
            this.subscriptionTierType = subscriptionType.getString();
        }
        this.showDetailedFooter = showDetailedFooter;
    }

    @JsonProperty("isDedicatedAol")
    public boolean isDedicatedAol() {
        return isDedicatedAol;
    }

    @JsonProperty("isCloudProviderConfigured")
    public boolean isCloudProviderConfigured() {
        return isCloudProviderConfigured;
    }
}
