package org.artifactory.ui.rest.model.admin.services.backups;

import com.google.common.collect.Maps;
import org.artifactory.api.config.CentralConfigService;
import org.artifactory.api.context.ArtifactoryContext;
import org.artifactory.api.context.ArtifactoryContextThreadBinder;
import org.artifactory.descriptor.backup.BackupDescriptor;
import org.artifactory.descriptor.config.CentralConfigDescriptor;
import org.artifactory.descriptor.repo.FederatedRepoDescriptor;
import org.jetbrains.annotations.NotNull;
import org.mockito.Mockito;
import org.testng.annotations.AfterMethod;
import org.testng.annotations.DataProvider;
import org.testng.annotations.Test;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

import static org.mockito.ArgumentMatchers.any;
import static org.mockito.Mockito.doNothing;
import static org.mockito.Mockito.mock;
import static org.mockito.Mockito.when;
import static org.testng.Assert.assertEquals;

/**
 * @author Alexei Vainshtein
 */
public class BackupTest {

    @AfterMethod
    public void tearDown() {
        ArtifactoryContextThreadBinder.unbind();
    }

    @Test
    public void testPopulateIncludeRepo() {
        ArtifactoryContext context = mock(ArtifactoryContext.class);
        ArtifactoryContextThreadBinder.bind(context);
        Map<String, FederatedRepoDescriptor> federatedRepositoriesMap = prepareDescriptor(context);
        Backup backup = new Backup();
        ArrayList<String> excludeRepos = new ArrayList<>();
        excludeRepos.add("fed-docker");
        backup.setExcludeRepos(excludeRepos);
        backup.populateIncludeRepo();
        List<String> includeRepos = backup.getIncludeRepos();
        assertEquals(includeRepos.size(), federatedRepositoriesMap.size() - excludeRepos.size());
    }

    @Test
    public void testSetExcludeRepos() {
        ArtifactoryContext context = mock(ArtifactoryContext.class);
        ArtifactoryContextThreadBinder.bind(context);
        prepareDescriptor(context);
        Backup backup = new Backup();
        ArrayList<String> excludeRepos = new ArrayList<>();
        excludeRepos.add("fed-docker");
        backup.setExcludeRepos(excludeRepos);
        List<String> excludedRepos = backup.getExcludeRepos();
        assertEquals(excludedRepos.size(), excludedRepos.size());
    }

    @Test(dataProvider = "actOnMissionControlProvider")
    public void testPopulatedFields(boolean shouldActOnMissionControl) {
        Backup backup = Mockito.spy(new Backup());
        doNothing().when(backup).populateExcludeRepo(any());
        doNothing().when(backup).populateIncludeRepo();
        BackupDescriptor backupDescriptor = new BackupDescriptor();
        backupDescriptor.setExportMissionControl(shouldActOnMissionControl);
        backup.populateditFields(backupDescriptor, true);
        assertEquals(backup.isExportMissionControl(), shouldActOnMissionControl);
    }

    @DataProvider
    public Object[][] actOnMissionControlProvider() {
        return new Object[][] {
                {true},
                {false}
        };
    }

    @NotNull
    private Map<String, FederatedRepoDescriptor> prepareDescriptor(ArtifactoryContext context) {
        CentralConfigService configService = mock(CentralConfigService.class);
        CentralConfigDescriptor configDescriptor = mock(CentralConfigDescriptor.class);
        Map<String, FederatedRepoDescriptor> federatedRepositoriesMap = populateFederatedReposMap();
        when(configDescriptor.getFederatedRepositoriesMap()).thenReturn(federatedRepositoriesMap);
        when(configService.getDescriptor()).thenReturn(configDescriptor);
        when(context.beanForType(CentralConfigService.class)).thenReturn(configService);
        return federatedRepositoriesMap;
    }

    @NotNull
    private Map<String, FederatedRepoDescriptor> populateFederatedReposMap() {
        FederatedRepoDescriptor repoDescriptor = new FederatedRepoDescriptor();
        repoDescriptor.setKey("fed-docker");
        Map<String, FederatedRepoDescriptor> federatedRepositoriesMap = Maps.newLinkedHashMap();
        federatedRepositoriesMap.put(repoDescriptor.getKey(), repoDescriptor);
        repoDescriptor = new FederatedRepoDescriptor();
        repoDescriptor.setKey("fed-docker1");
        federatedRepositoriesMap.put(repoDescriptor.getKey(), repoDescriptor);
        return federatedRepositoriesMap;
    }
}