package org.artifactory.ui.rest.model.artifacts.browse.treebrowser.action.recalculateindex;

import com.google.common.collect.Maps;
import org.artifactory.addon.AddonsManager;
import org.artifactory.addon.yum.YumAddon;
import org.artifactory.api.config.CentralConfigService;
import org.artifactory.api.context.ArtifactoryContext;
import org.artifactory.api.context.ArtifactoryContextThreadBinder;
import org.artifactory.descriptor.config.CentralConfigDescriptor;
import org.artifactory.descriptor.repo.FederatedRepoDescriptor;
import org.artifactory.descriptor.repo.LocalRepoDescriptor;
import org.testng.annotations.AfterMethod;
import org.testng.annotations.Test;

import java.util.Map;

import static org.mockito.Mockito.mock;
import static org.mockito.Mockito.times;
import static org.mockito.Mockito.verify;
import static org.mockito.Mockito.when;

/**
 * @author Alexei Vainshtein
 */
public class YumIndexCalculatorTest {

    @AfterMethod
    public void tearDown() {
        ArtifactoryContextThreadBinder.unbind();
    }

    @Test
    public void testCalculateIndex() throws Exception {
        ArtifactoryContext context = mock(ArtifactoryContext.class);
        ArtifactoryContextThreadBinder.bind(context);
        AddonsManager addonsManager = mock(AddonsManager.class);
        YumAddon yumAddon = mock(YumAddon.class);
        when(addonsManager.addonByType(YumAddon.class)).thenReturn(yumAddon);
        when(context.beanForType(AddonsManager.class)).thenReturn(addonsManager);
        CentralConfigDescriptor descriptor = mock(CentralConfigDescriptor.class);
        Map<String, LocalRepoDescriptor> reposMap = Maps.newLinkedHashMap();
        String repoName = "repo";
        FederatedRepoDescriptor federatedRepoDescriptor = new FederatedRepoDescriptor();
        reposMap.put(repoName, federatedRepoDescriptor);
        when(descriptor.getLocalAndFederatedRepositoriesMap()).thenReturn(reposMap);
        CentralConfigService service = mock(CentralConfigService.class);
        when(service.getDescriptor()).thenReturn(descriptor);
        when(context.getCentralConfig()).thenReturn(service);

        YumIndexCalculator indexCalculator = new YumIndexCalculator();
        indexCalculator.setRepoKey(repoName);
        indexCalculator.calculateIndex();
        verify(yumAddon, times(1)).requestRpmMetadataCalculation(federatedRepoDescriptor, null, true);
    }
}