package org.artifactory.ui.rest.service.admin.configuration.repositories.util;

import org.artifactory.federation.FederatedRepoService;
import org.artifactory.rest.common.service.ArtifactoryRestRequest;
import org.artifactory.rest.common.service.ArtifactoryRestResponse;
import org.artifactory.rest.exception.BadRequestException;
import org.testng.annotations.Test;

import static org.apache.http.HttpStatus.SC_BAD_REQUEST;
import static org.apache.http.HttpStatus.SC_OK;
import static org.mockito.Mockito.verify;
import static org.mockito.Mockito.times;
import static org.mockito.Mockito.doAnswer;
import static org.mockito.Mockito.doNothing;
import static org.mockito.Mockito.when;
import static org.mockito.Mockito.mock;
import static org.mockito.Mockito.doThrow;

/**
 * @author Alexei Vainshtein
 */
public class MigrateLocalToFederatedRepositoryTest {

    @Test
    public void testExecute() {
        FederatedRepoService repoService = mock(FederatedRepoService.class);
        doNothing().when(repoService).migrate("repo");
        MigrateLocalToFederatedRepository migrate = new MigrateLocalToFederatedRepository(repoService);
        ArtifactoryRestRequest request = mock(ArtifactoryRestRequest.class);
        when(request.getImodel()).thenReturn("repo");
        ArtifactoryRestResponse restResponse = mock(ArtifactoryRestResponse.class);
        doAnswer(invocationOnMock -> restResponse).when(restResponse).info(migrate.SUCCESSFULLY);
        doAnswer(invocationOnMock -> restResponse).when(restResponse).responseCode(SC_OK);
        migrate.execute(request, restResponse);
        verify(restResponse, times(1)).responseCode(SC_OK);
        verify(restResponse, times(1)).info(migrate.SUCCESSFULLY);
    }

    @Test
    public void testExecuteWithException() {
        FederatedRepoService repoService = mock(FederatedRepoService.class);
        BadRequestException exception = new BadRequestException("failed migration");
        doThrow(exception).when(repoService).migrate("repo");
        MigrateLocalToFederatedRepository migrate = new MigrateLocalToFederatedRepository(repoService);
        ArtifactoryRestRequest request = mock(ArtifactoryRestRequest.class);
        when(request.getImodel()).thenReturn("repo");
        ArtifactoryRestResponse restResponse = mock(ArtifactoryRestResponse.class);
        doAnswer(invocationOnMock -> restResponse).when(restResponse).error(exception.getMessage());
        doAnswer(invocationOnMock -> restResponse).when(restResponse).responseCode(SC_BAD_REQUEST);
        migrate.execute(request, restResponse);
        verify(restResponse, times(1)).responseCode(SC_BAD_REQUEST);
        verify(restResponse, times(1)).error(exception.getMessage());
    }
}