package org.artifactory.rest.resource.servicetrust;

import org.artifactory.servicetrust.ServiceTrustService;
import org.artifactory.servicetrust.ServiceTrustUseCase;
import org.mockito.Mockito;
import org.testng.annotations.Test;

import javax.ws.rs.core.Response;
import java.util.Optional;

import static org.artifactory.rest.resource.servicetrust.ServiceTrustResourceRegisterTokenTest.assertResponse;
import static org.mockito.ArgumentMatchers.any;
import static org.mockito.Mockito.when;
import static org.testng.Assert.assertEquals;

public class ServiceTrustResourceCreateTokenTest {

    @Test
    public void whenUseCaseIsUnknownThen404() {
        ServiceTrustResource resource = new ServiceTrustResourceForTest();
        ServiceTrustService service = Mockito.mock(ServiceTrustService.class);
        when(service.findUseCase(any())).thenReturn(Optional.empty());
        resource.setServiceTrustService(service);

        Response response = resource.createToken("unknown");

        assertResponse(response, 404, "Unknown use case");
    }

    @Test
    public void whenUseCaseIsOkThen200() {
        ServiceTrustResource resource = new ServiceTrustResourceForTest();
        ServiceTrustService service = Mockito.mock(ServiceTrustService.class);
        when(service.findUseCase(any())).thenReturn(Optional.of(ServiceTrustUseCase.ARTIFACTORY_COLD));
        when(service.getPairingToken(any(), any(), any(), any(), any())).thenReturn("token");
        resource.setServiceTrustService(service);

        Response response = resource.createToken("artifactory-cold");

        int status = response.getStatus();
        String token = ((PairingResponse) response.getEntity()).getPairingToken();
        assertEquals(status, 200);
        assertEquals(token, "token");
    }

    private static class ServiceTrustResourceForTest extends ServiceTrustResource {
        @Override
        String getRestApiUrl() {
            return "";
        }

        @Override
        String getBaseUrl() {
            return "";
        }
    }
}