package org.artifactory.rest.resource.system;

import org.artifactory.api.mail.MailService;
import org.artifactory.api.rest.mail.MailMessageRequest;
import org.artifactory.rest.resource.email.EmailResource;
import org.artifactory.util.EmailException;
import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.mockito.Mock;
import org.mockito.MockitoAnnotations;
import org.mockito.junit.MockitoJUnitRunner;

import javax.servlet.http.HttpServletResponse;

import static org.mockito.ArgumentMatchers.any;
import static org.mockito.ArgumentMatchers.eq;
import static org.mockito.Mockito.doNothing;
import static org.mockito.Mockito.doThrow;
import static org.mockito.Mockito.times;
import static org.mockito.Mockito.verify;
import static org.testng.AssertJUnit.assertEquals;

@RunWith(MockitoJUnitRunner.class)
public class MailResourceTest {
    @Mock
    private MailService mailService;

    @Before
    public void beforeMethod() throws Exception {
        MockitoAnnotations.initMocks(this);
    }

    @Test
    public void testSendMail() {
        EmailResource mailResource = new EmailResource(mailService);
        doNothing().when(mailService).sendMail(any(), eq("subject"), any());
        MailMessageRequest mailReq = new MailMessageRequest("a@a.com", "subject", "body");
        assertEquals(mailResource.sendMail(mailReq).getStatus(), HttpServletResponse.SC_OK);
        verify(mailService, times(1)).sendMail(new String[] {"a@a.com"}, "subject", "body");
    }

    @Test
    public void testSendMailFail() {
        EmailResource mailResource = new EmailResource(mailService);
        doThrow(new EmailException("err")).when(mailService).sendMail(any(), eq("1subject1"), any());
        MailMessageRequest mailReq = new MailMessageRequest("a@a.com", "1subject1", "body");
        assertEquals(HttpServletResponse.SC_BAD_REQUEST, mailResource.sendMail(mailReq).getStatus());
        verify(mailService, times(1)).sendMail(new String[] {"a@a.com"}, "1subject1", "body");
    }

}